Welcome to ClientVPS Mirrors

Help for package RcmdrPlugin.WorldFlora
Type: Package
Title: R Commander Plug-in for the 'WorldFlora' Package
Version: 1.3
Date: 2023-5-28
Author: Roeland Kindt ORCID iD [cre, aut]
Maintainer: Roeland Kindt <RoelandCEKindt@gmail.com>
Depends: R (≥ 3.5.0), WorldFlora (≥ 1.13-2)
Imports: Rcmdr (≥ 2.4-0)
Description: An R Commander plug-in for the 'WorldFlora' package. It was mainly developed to show work flows and scripts for first-time users.
License: GPL-3
Suggests: data.table, utils, stringr
Packaged: 2023-05-28 07:55:50 UTC; RKINDT
NeedsCompilation: no
Repository: CRAN
Date/Publication: 2023-05-28 08:30:02 UTC

Internal RcmdrPlugin.WorldFlora Objects

Description

Internal RcmdrPlugin.WorldFlora objects.

Details

These are not to be called by the user.


Data set to test WorldFlora GUI

Description

This data set can be used to test the WorldFlora menu interface.

Usage

data(WFO.test)

Examples

data(WFO.test)

Getting Started with the GUI and WorldFlora

Description

File with some instructions for first time users.

Usage

WorldFlora.get.started()
browseWFOmanual()
helpWorldFlora()
browseRpub()
browseRpub2023()

References

World Flora Online. An Online Flora of All Known Plants. http://www.worldfloraonline.org

Kindt, R. 2020. WorldFlora: An R package for exact and fuzzy matching of plant names against the World Flora Online taxonomic backbone data. Applications in Plant Sciences 8(9): e11388

Kindt, R. 2023. Standardizing tree species names of GlobalTreeSearch with WorldFlora while testing the faster matching function of WFO.match.fuzzyjoin. https://rpubs.com/Roeland-KINDT/996500

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.